# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`local_rpm_repo`](#local_rpm_repo): Creates and hosts the specified RPM repositories.

### Defined types

* [`local_rpm_repo::puppet_source`](#local_rpm_repopuppet_source): Repo with rpm files sourced from a puppet file server.
* [`local_rpm_repo::reposync_source`](#local_rpm_reporeposync_source): Repo with rpm files sourced via a reposync call.
* [`local_rpm_repo::tar_source`](#local_rpm_repotar_source): Repo with instance data retrieve from a tar file.
* [`local_rpm_repo::wget_source`](#local_rpm_repowget_source): Repo with rpm files sourced via a reposync call.

### Data types

* [`Local_rpm_repo::PuppetUrl`](#local_rpm_repopuppeturl): Matches puppet file server source url strings
* [`Local_rpm_repo::RepoData`](#local_rpm_reporepodata): Repo configuration file used by reposync to download the data
* [`Local_rpm_repo::RepoGPGKey`](#local_rpm_reporepogpgkey): GPG Key file definition
* [`Local_rpm_repo::RepoUrl`](#local_rpm_reporepourl): Valid source URL types for reposync
* [`Local_rpm_repo::SourceUrl`](#local_rpm_reposourceurl): URL types for tar source data.
* [`Local_rpm_repo::Version`](#local_rpm_repoversion): Allowed version semantics on our data.

## Classes

### <a name="local_rpm_repo"></a>`local_rpm_repo`

A simple class to create and manage locally maintained repositories using
tar file containing the RPMs.

#### Examples

##### Definition of three repositories

```puppet
class { 'local_rpm_repo':
  base_url_default => 'http://bin.example.com/data/',
  mirror_fqdn      => 'yum.example.com',
  repo_list        => {
    'repo1' => { version => '1.0.0.0' },
    'repo2' => { version => '1.0.0.0' },
    'repo3' => { version => '1.0.0.0' },
  },
}
```

#### Parameters

The following parameters are available in the `local_rpm_repo` class:

* [`mirror_fqdn`](#mirror_fqdn)
* [`base_url_default`](#base_url_default)
* [`repo_base_path`](#repo_base_path)
* [`repo_base_cache_path`](#repo_base_cache_path)
* [`repo_list`](#repo_list)
* [`suppress_cron_stdout`](#suppress_cron_stdout)

##### <a name="mirror_fqdn"></a>`mirror_fqdn`

Data type: `Stdlib::Fqdn`

Fully Qualified Domain Name which will be used as the apache vhost name on
this server. Note that this FQDN should resolve to this server.

##### <a name="base_url_default"></a>`base_url_default`

Data type: `Optional[Local_rpm_repo::SourceUrl]`

This specifies the URL from which the repo tar should be extracted or the
remote files should be replicated if a specific url is not provided in
repo_list. When used, the application assumes the source data is located
within the specified directory.

For example, given a repo named 'test-repo' at version '1.0.5.1':
  * `http://bin.example.org/data` - expects http://bin.example.org/data/test-repo-1.0.5.1.tar to exist
  * `puppet:///repo_files` - expects the folder structure 'puppet:///repo_files/test-repo/1.0.5.1'

##### <a name="repo_base_path"></a>`repo_base_path`

Data type: `Stdlib::AbsolutePath`

Absolute path to the parent directory of the yum repository

Default value: `'/var/yumrepos'`

##### <a name="repo_base_cache_path"></a>`repo_base_cache_path`

Data type: `Stdlib::AbsolutePath`

Absolute path to the parent directory of the yum repository cache
directory.

Default value: `'/var/cache/yumrepos'`

##### <a name="repo_list"></a>`repo_list`

Data type: `Hash[String, Local_rpm_repo::RepoData]`

A hash where the keys are the names of the repos to be deployed. The
following options are supported for each repo:
* version        - version of the source repo file
* source_prefix  - prefix of the file, defaults to the repo name.

@note At least one repository must be specified

Default value: `{}`

##### <a name="suppress_cron_stdout"></a>`suppress_cron_stdout`

Data type: `Boolean`

When enabled stdout generated by the createrepo command(s) will be directed
to `/dev/null`. This is very helpful if these messages would be emailed
unnecessarily in your environment.

Default value: ``true``

## Defined types

### <a name="local_rpm_repopuppet_source"></a>`local_rpm_repo::puppet_source`

This type is an implementation detail and should not be declared directly!

#### Parameters

The following parameters are available in the `local_rpm_repo::puppet_source` defined type:

* [`version`](#version)
* [`base_url`](#base_url)
* [`prefix`](#prefix)
* [`versions_path`](#versions_path)

##### <a name="version"></a>`version`

Data type: `Local_rpm_repo::Version`

Version number to instantiate.

##### <a name="base_url"></a>`base_url`

Data type: `Local_rpm_repo::PuppetUrl`

Puppet path to the RPM directory. See the repo::base_url_default for
further details.

##### <a name="prefix"></a>`prefix`

Data type: `String`

String prepended to the version number to determine the source tar file
name. Note that this field is a namevar.

Default value: `$name`

##### <a name="versions_path"></a>`versions_path`

Data type: `Stdlib::AbsolutePath`

Absolute path to the versions subdirectory for this repository.

### <a name="local_rpm_reporeposync_source"></a>`local_rpm_repo::reposync_source`

This type is an implementation detail and should not be declared directly!

#### Parameters

The following parameters are available in the `local_rpm_repo::reposync_source` defined type:

* [`base_url`](#base_url)
* [`versions_path`](#versions_path)
* [`gpgcheck`](#gpgcheck)
* [`gpgkey`](#gpgkey)
* [`array_arch`](#array_arch)
* [`description`](#description)
* [`initial_timeout`](#initial_timeout)

##### <a name="base_url"></a>`base_url`

Data type: `Local_rpm_repo::RepoUrl`

Source against which the reposync command will execute

##### <a name="versions_path"></a>`versions_path`

Data type: `Stdlib::AbsolutePath`

Absolute path to the versions subdirectory for this repository. This will be
used as the target for the reposync command.

##### <a name="gpgcheck"></a>`gpgcheck`

Data type: `Boolean`

When true, this module will attempt to initialize the gpgkey file & will
ensure it is valid during this configuration

##### <a name="gpgkey"></a>`gpgkey`

Data type: `Optional[Local_rpm_repo::RepoGPGKey]`

This parameter must be included when gpgcheck is enabled. Includes the
partial name of the keyfile as well as it's desired content.

Default value: ``undef``

##### <a name="array_arch"></a>`array_arch`

Data type: `Array[String]`

List of processor architectures to iterate through.

Default value: `[]`

##### <a name="description"></a>`description`

Data type: `String`

When present, the config file can have a different "name" subkey in its INI.

Default value: `$name`

##### <a name="initial_timeout"></a>`initial_timeout`

Data type: `Integer`

Execution timeout on the first synchronization of the repository.

Default value: `300`

### <a name="local_rpm_repotar_source"></a>`local_rpm_repo::tar_source`

This type is an implementation detail and should not be declared directly!

#### Parameters

The following parameters are available in the `local_rpm_repo::tar_source` defined type:

* [`version`](#version)
* [`base_url`](#base_url)
* [`prefix`](#prefix)
* [`versions_path`](#versions_path)

##### <a name="version"></a>`version`

Data type: `Local_rpm_repo::Version`

Version number to instantiate.

##### <a name="base_url"></a>`base_url`

Data type: `Variant[Stdlib::Httpurl, Stdlib::Httpsurl]`

Location containing the source tar file. See the repo::base_url_default for
further details.

##### <a name="prefix"></a>`prefix`

Data type: `String`

String prepended to the version number to determine the source tar file
name. Note that this field is a namevar.

Default value: `$name`

##### <a name="versions_path"></a>`versions_path`

Data type: `Stdlib::AbsolutePath`

Absolute path to the versions subdirectory for this repository.

### <a name="local_rpm_repowget_source"></a>`local_rpm_repo::wget_source`

This type is an implementation detail and should not be declared directly!

#### Parameters

The following parameters are available in the `local_rpm_repo::wget_source` defined type:

* [`base_url`](#base_url)
* [`versions_path`](#versions_path)
* [`cut_dir_count`](#cut_dir_count)
* [`initial_timeout`](#initial_timeout)

##### <a name="base_url"></a>`base_url`

Data type: `Local_rpm_repo::RepoUrl`

Source against which the reposync command will execute

##### <a name="versions_path"></a>`versions_path`

Data type: `Stdlib::AbsolutePath`

Absolute path to the versions subdirectory for this repository. This will be
used as the target for the wget command.

##### <a name="cut_dir_count"></a>`cut_dir_count`

Data type: `Integer`

When wget recursively downloads the contents of a webpage the default
behavior is to create a folder for each subdirectory along the path. This
parameter controls the number of directories to cut making the resulting
tree more concise.

##### <a name="initial_timeout"></a>`initial_timeout`

Data type: `Integer`

Execution timeout on the first synchronization of the repository.

Default value: `300`

## Data types

### <a name="local_rpm_repopuppeturl"></a>`Local_rpm_repo::PuppetUrl`

Matches puppet file server source url strings

Alias of

```puppet
Pattern[/(?i:^puppet?:\/\/)/]
```

### <a name="local_rpm_reporepodata"></a>`Local_rpm_repo::RepoData`

Repo configuration file used by reposync to download the data

Alias of

```puppet
Variant[Struct[
    source_type        => Enum['puppet'],
    version            => Local_rpm_repo::Version,
    Optional[prefix]   => String,
    Optional[base_url] => Local_rpm_repo::PuppetURL,
  ], Struct[
    source_type        => Enum['tar'],
    version            => Local_rpm_repo::Version,
    Optional[prefix]   => String,
    Optional[base_url] => Local_rpm_repo::SourceUrl,
  ], Struct[
    source_type               => Enum['reposync'],
    base_url                  => Local_rpm_repo::RepoUrl,
    gpgcheck                  => Boolean,
    array_arch                => Array[String],
    Optional[gpgkey]          => Local_rpm_repo::RepoGPGKey,
    Optional[description]     => String,
    Optional[initial_timeout] => Integer,
  ], Struct[
    source_type               => Enum['wget'],
    base_url                  => Local_rpm_repo::RepoUrl,
    cut_dir_count             => Integer,
    Optional[initial_timeout] => Integer,
  ]]
```

#### Parameters

The following parameters are available in the `Local_rpm_repo::RepoData` data type:

* [`source_type`](#source_type)
* [`version`](#version)
* [`baseurl`](#baseurl)
* [`enabled`](#enabled)
* [`gpgcheck`](#gpgcheck)
* [`array_arch`](#array_arch)
* [`description`](#description)
* [`initial_timeout`](#initial_timeout)

##### <a name="source_type"></a>`source_type`

Determines the type of source from which the repo content will be retrieved.

##### <a name="version"></a>`version`

Puppet and tar type repositories use these version numbers in their
deployment model.

##### <a name="baseurl"></a>`baseurl`

Source from which the repo content will be downloaded.

##### <a name="enabled"></a>`enabled`

See man yum.conf

##### <a name="gpgcheck"></a>`gpgcheck`

See man yum.conf

##### <a name="array_arch"></a>`array_arch`

Reposync based repositories can be multi-architecture

##### <a name="description"></a>`description`

Human readable string used in the declaration of the repository.

##### <a name="initial_timeout"></a>`initial_timeout`

Controls the command timeout via exec when the sync runs the first time. Not
all modes support this parameter. Note that it defaults to 300 seconds when
left out.

### <a name="local_rpm_reporepogpgkey"></a>`Local_rpm_repo::RepoGPGKey`

GPG Key file definition

Alias of

```puppet
Struct[=>]
```

#### Parameters

The following parameters are available in the `Local_rpm_repo::RepoGPGKey` data type:

* [`name`](#name)
* [`content`](#content)

##### <a name="name"></a>`name`

Filename of the resulting keyfile

##### <a name="content"></a>`content`

Raw content of the keyfile

### <a name="local_rpm_reporepourl"></a>`Local_rpm_repo::RepoUrl`

Valid source URL types for reposync

Alias of

```puppet
Variant[Stdlib::Httpurl, Stdlib::Httpsurl, Pattern[/(?i:^ftp?:\/\/)/]]
```

### <a name="local_rpm_reposourceurl"></a>`Local_rpm_repo::SourceUrl`

URL types for tar source data.

Alias of

```puppet
Variant[Stdlib::Httpurl, Stdlib::Httpsurl]
```

### <a name="local_rpm_repoversion"></a>`Local_rpm_repo::Version`

Allowed version semantics on our data.

Alias of

```puppet
Pattern[/\d[.]\d[.]\d[.]\d/]
```

